import * as cdk from 'aws-cdk-lib';
import * as constructs from 'constructs';
/**
 * Manage a Fastly service active version.
 *
 * @schema CfnActiveVersionProps
 */
export interface CfnActiveVersionProps {
    /**
     * Alphanumeric string identifying the service. Read-only.
     *
     * @schema CfnActiveVersionProps#ServiceId
     */
    readonly serviceId: string;
    /**
     * The number of the version to be activated.
     *
     * @schema CfnActiveVersionProps#VersionNumber
     */
    readonly versionNumber: number;
}
/**
 * Converts an object of type 'CfnActiveVersionProps' to JSON representation.
 */
export declare function toJson_CfnActiveVersionProps(obj: CfnActiveVersionProps | undefined): Record<string, any> | undefined;
/**
 * A CloudFormation `Fastly::Services::ActiveVersion`
 *
 * @cloudformationResource Fastly::Services::ActiveVersion
 * @stability external
 * @link https://github.com/aws-ia/cloudformation-fastly-resource-providers.git
 */
export declare class CfnActiveVersion extends cdk.CfnResource {
    /**
    * The CloudFormation resource type name for this resource class.
    */
    static readonly CFN_RESOURCE_TYPE_NAME = "Fastly::Services::ActiveVersion";
    /**
     * Resource props.
     */
    readonly props: CfnActiveVersionProps;
    /**
     * Create a new `Fastly::Services::ActiveVersion`.
     *
     * @param scope - scope in which this resource is defined
     * @param id    - scoped id of the resource
     * @param props - resource properties
     */
    constructor(scope: constructs.Construct, id: string, props: CfnActiveVersionProps);
}
